@@ -1,5 +1,5 @@
 from .da import DA
-from .da_meta import regenerate_da_metadata
+from .da_meta import regenerate_meta_file
 from .protectfile import ProtectFile, get_hash
 
-__version__ = '0.0.3'
+__version__ = '0.1.0'
